#!/bin/bash
#SBATCH --job-name="MUSA-presim"
#SBATCH -D .
#SBATCH --output=./logs_presim_generation_%j.out
#SBATCH --error=./logs_presim_generation_%j.err
#SBATCH --ntasks=1
#SBATCH --cpus-per-task=1
#SBATCH --time=0:30:00

function generate_presim () {
  config_file=$1
  config_name=${config_file::-5}
  mode=${config_name:(-4)}
  aux=${config_name::-5}
  PADCORES=${aux:(-6)}
  app=$2
  sim_folder=musa_out_${app}_${PADCORES}
  greasyfile=${sim_folder}".${config_name}.${mode}.allcores.greasy"
  if [ -e $greasyfile ]; then
    rm $greasyfile
  fi
  total_greasy=$3
  this_sim_folder=${sim_folder}/${config_name}
  mkdir -p $this_sim_folder
  echo "----- Generating greasy files for ${config_name::-12} with $PADCORES threads and $mode mode -----"
  tasksim_presim -d trace_ts -o ${config_name}.dat -c ${config_file} -t ${this_sim_folder} -g -s >> $greasyfile
  cat $greasyfile >>$total_greasy
  rm $greasyfile
  echo "Done."
}

### Specific for mn4
module load musa/3.1
app=APP
memory_mode=MODE

### do you want to keep output logs of mem statistics?
export TS_SIM_LOG=1

if [ $memory_mode -ne 0 ]; then
  files=$(ls *[MEMO,BRST].conf)
else
  files=$(ls *BRST.conf)
fi
total_greasy=all_${app}_sims.greasy

if [ -e $total_greasy ]; then
  rm $total_greasy
fi

for config_file in $files
do
  if [[ $config_file == *BRST*  ]]; then
    export TS_SIM_ONLY_MEM=0
    export TS_SIM_MEM=0
  else
    export TS_SIM_ONLY_MEM=1
    export TS_SIM_MEM=1
  fi
  generate_presim $config_file $app $total_greasy
done

sed -e "s/GREASY_NAME/${total_greasy}/g" < ${MUSA_HOME}/tasksim/etc/examples/step2_presim/launch_musa_presim.bash > launch_all_musa_presims.bash
